
# q-expansion of newform 50.24.a.d, downloaded from the LMFDB on 10 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 50
weight = 24
poly_data = [-54810, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-30, 60], 1]]

hecke_ring_character_values = None
aps_data = [[2048, 0], [9258, -17], [0, 0], [2207867554, -236871], [97508619912, -74860038], [-1291591529342, 264326436], [-65834431300266, 14315569236], [-880444209100, 59019006348], [-2006418052671282, 148453206543], [-54192732736893690, 1566250154136], [-141267120965323948, -3162382222446], [163427983774183234, 15003959722056], [-2689205701507336638, -38270620041084], [4912103235248195818, -154386539243541], [9229504066042130154, -694440615674871], [3367793229633696378, 2897406132365196], [202215730305659597220, -3281906771429688], [133644319703115047702, 27045528407419248], [439129514005523155774, -25856561070208143], [-711145288532621425668, 18238574910506778], [1368925045383757315438, 222989074087307076], [-8179118199070271339560, -154924172267264892], [12459157399804918004778, -466086970968942105], [-34543355553827379533190, 752593846921196040], [-71056858623922743400106, -3807221816429239860], [11431731934198097234142, -11476115462166947064], [-63539956306007587373162, -9785717643136920165], [-238569944811507422758626, 8940145270852816317], [-22631732808822105116650, -18151648703373317976], [296449293601591644667038, -25312621796935948872], [-328344434838090025103126, -85247785275776461503], [1039109732505192814323432, 62959497344180524566], [-1386079301647838898649146, -136246939604624965536], [1519606847212776140005940, 331338465912470623992], [-3736961985199555055569650, -75073749055943982120], [-923487461437894096390948, -768431170436412642030], [12189746465981899053818554, -971417973486362786136], [-17416519001104889255985182, -1475841148066422145845], [36942708711399360494978874, 1972862413218181279557], [-961614447834591339694902, 1714712244624595731240], [-88721986299858075667946820, -788214365046241133616], [148715356325766765493081502, -2157777991312762165776], [29906221416258169035061692, 15486312081822656391558], [-300231466729754732057606042, 1403628545018734347780], [-230670260748581858753398326, 124069890720510045612], [-264113999760625050390863560, -8540169345923942090304], [-176965542666801172504728568, 51537065650852024626030], [-965049064245353653935453122, 11197430673787838348307], [-295056586480458524375529666, -30894118909617520681119], [-594084931182014267425913650, 31392631019703197499552], [-874311294539300872162444962, -135960511286077381365876], [-1645753567377725956631654520, 4730296325553086522508], [588346714061294364098748122, 99654949377095285865780], [-797171943965326316563500648, -213508458246575971409670], [2185607233850103878540965134, -431211225006859842972504], [4982646045303067705939267998, 437747766150302927976447], [190571662455644221566252390, 1072175891968342561241664], [-7766474686794393828645429748, 473935139273412453331926], [-3566030065587638231714989646, -1104896675313223592721336], [7471654805590867090303097442, -941698460647715319701460], [10320625559554571323847000458, -83589169804282892120733], [13100110791397394129969207058, -1699941754729014944868720], [10554852750997288742396367694, -1512219743366115701077695], [-62838345315159783855868221708, -1390777582269864251497986], [35856049675465440003297067078, 2585034516848104877725224], [16870795868930755943791112274, 5017850543034199785909492], [-9372029902738981382852322928, -2833016739223024278764658], [-105974767478197144619266216706, -3576843100236379217960520], [177615064642581684076473076014, -1960356308111895047146227], [248923388687685810566742330230, 896610353875993566661392], [57681965653096181904771105678, 11917684686111466129400376], [-187087107978794594693510230920, 9932024044230648873874416], [-53031974774936799839434942766, -10076210250247134870806259], [-102860589289882175375175060302, -35364357027822987056059560], [-258300695172936034813839696340, -27631621920624520281467364], [336567208673458368711348559038, 39476971207053079019641539], [-640314913144174965805268328210, 18836135850093694986455712], [-965921104739203122363755706686, 15386893275276029137397508], [74844084550349116206433674162, -64107093201784091175126816], [-841260812182241494507652213470, -84988169168792273730051444], [-1292369433151212873138491654340, 8223052452647185827076392], [1365796862176536378746103374462, 44773431897245205672817560], [1306810046439432356900814016092, -28887621512539383657603090], [-31805482291607387079289976762, 235774987539573718321611804], [-1304176244257261871768275684600, 188723360417030218348302816], [2911039940951777680080413332098, -34867663854615519127948449], [70010578637250996991419097770, -225882980788667163349003452], [3698181523739225423667925801894, 98092495216185784559630640], [-654988662666569632174981918218, 80087266613675968166333160], [752292603750958194918302633758, -29373682294907749950661269], [-2750177013797766064465369314426, 119168882308428143994115677], [12251586284229394886572498549320, 33947260483981664214873540], [-6400437033942977266345613837366, 165093945845419181692038861], [4769522525844118251221927559432, 103597047855688446976562154], [1150277123880401203167553878740, 395992541572655203111527756], [6224659731343419248131191198198, 1074243952815537081848840739], [643274154415545580059723723510, -294039754095007675984696992], [-1203799621363659203422790994438, 538271694171245994959214720], [991126986742304636174686432858, 1410065049070766210331777939], [-15652449909548751732495341688058, 744726810111429846273397848], [-6305686672001708082921830205266, -425011585596225902229128679], [-21947212779286873608860417015286, -678570941931010492553564472], [-56943762478694915898070875238422, 600874482161824064493719319], [21533773484246551186427343704610, -401075003817027709173974628], [9999480695759623741020396719312, -3507643471355315035543219770], [8671585078928133411475354583134, -976862429412302268189278064], [47704751677370420865052956839574, -1225477837119685870331568423], [-132131068787066043664248909110802, -319953873797891077792724784], [-71430181293466130539792431800640, -1981370022335576512040136996], [-53553377830203266226279266267518, 2558902685021797851594364572], [111031596199339798958723489623834, 2024078968106900087138926281], [-3501586937293377466251641855462, -12733343939580523876648280412], [-9955932084877069046202725751906, -7348817797667481461167104660], [-147343021555412242649400587604820, 4544065315258052087670690420], [-90668360990527457628239578016548, 801637247037749979730052034], [35611465607487452322454470787722, 8910271605189782568318040980], [85055147256209485931773754701618, 17094635861417037638724640419], [-81849477714649745079812039028246, -10942538744430144947224102131], [-138067858971624182727657593168622, -2432883613484502580852981044], [-118768668540075860118866177633700, -6548479848399450016553379696], [-271730522363231589671831077384258, 8214283048858695087785357904], [292281874103039206323762079669798, 4182440714583499244663749620], [-58680967733069409248788249487526, 40113150089137212799248702372], [152295438526576602284350586081658, -26046985719996362044790800173], [52235836150721865532090865360672, -37467597934292469881663167110], [116628987917216570995392774504582, -43357160708992341246967381368], [780738975149394572423625742105310, 5982551978841010358957468088], [348540278518558543982772791959080, -29164131115313252757980728500], [-136402057643512288059656531496446, 9494558432468903453872388769], [434553437718352734146207415453898, 4779187424310834340764014448], [1149079922996322320282404736123420, -25635594338088494944858605576], [73928113188198388349844099814758, 66784662353407438868379293475], [49268770130985118938953697106292, 60638324448257735848766140266], [206632663408504356667601273728834, -38400787039002853953633528384], [-1269442993243965408352942346453238, 68875971968261447575008472512], [-1632396455695921656786494312695150, -53221429403087251172357051352], [621699546811374069066987862100298, 73603873946720428702329588300], [566645617581032258206990787647654, 33722711762522621543254357389], [-57604904832194619666824514385566, -11308400171386878441118796244], [-255370053539972944264542279617190, 217010733408909263770179317568], [2645285234201943024655309702226312, -44843791297359322431166881078], [2080528105436107696028156348792622, 166820326426523268484778151864], [-631610549997625848600815140986722, 49312020547047650010238098567], [-2736567958826416399704956365729986, -145921205282206336407922010427], [-3329574099341908644667484194393450, 13930663446777916464498858672], [1858878176446939846408912812299280, -420830851624596074194687266372], [4973900587168941197273677173804058, -15748730271085098365140139892], [46532499595723496562219763095174, 688308516636479339052598798392], [-3905626189775402541173564176779820, 214698342452943846983593465296], [-4668548035062071445274113494315322, -19164002234559633046893073401], [3952400478468704003268194957111194, -345232983792588461731662338160], [-1941826566616505315314494201319158, -579837397552135581685262695380], [5195440066002144626190250970651578, 317642883557064264584871029055], [-299643704995872006640776614459406, -383394328163749456646356576215], [465089370659480671189262992823974, 1028823384159308462435158882977], [-4588586748496696185078297511084668, 468014527748313917897602339170], [3983896709396982051123912672008720, -303032400323534758637988464124], [7792960161784535739797080133389770, 481410164747678899760068726980], [-1200079299490869560143109524174706, -1109463296493802685354187690780], [-10864692587203558760540168114845818, -126019429347036824353928771136], [2230355939577882262549233290462094, 868644444840003835486560135585], [-4378049387370022842501102478733802, -867754789403191435077285091536], [-5662308323239948262158173436747406, 284197686574896158336245713825], [-22482214918932960607191411905522688, 248190936120368726042538069030], [-4980022305227002149665179493774346, -916960748067836556389533393596], [-9471123322463621929693950100624962, -19218522402241756566103071801], [20890592379840548077102004398202372, -401133840326489084089675503510], [-19375247694314689912210199021989286, 2035507180801411863160303002948], [9847853511290444147706668055232130, -2271473722997682240198096814824], [-57010213865949721347152987835370422, 292818123394616864144734608564], [-6234330041229716398038747036249780, -621428683369255451808585100884], [1489836020347718603534024279661302, 612445538192138855526589913376], [2998146589257575190488605917805092, -1448774632698351744939107766210], [-37360077533880693386085600695831042, -2794640083613223982027222005108], [-7003866868535866346472993207832000, 1064599235013402529770745534536], [-69811756129779852258396286327128870, 477538180803557242925425825752], [-27906641031205989267924563161487968, -401939572792602193315561796418], [-28631880068486429633365038039279858, -3485552635076205859279208077536], [-22131786091853975709698385701940002, 2896778645069360659221844454607], [-29551671623317566413158827176881210, 1266198124219301139267601217664], [-73239297655779310581933714499896446, 3201992576286038398288671434109], [-25945239566267599914974387009350008, -2886548620954991553037371545082], [14474278765124263254714445458443098, -2863059165753106865864029166124], [-62078296039486580051739301210239666, -5167053776778537376444605931404], [-97587961512654150621057634335821802, 1945467674893210783438283058999], [-26830667503621209156983403790885650, -7405754318007475426703499996216], [-120507658609672164409819876817458886, -410358987517640607598539475512], [-200153282144800992186846843370382, 7304757244229470124308444233363], [52145732160384005270221869671505650, 2609382975845824482754252756572], [13099265052961419843970979825241252, -4382415366871554971600937644790], [199273209557677192469071294728596158, -818661977502979113957587152032], [205879358578569041316211813763460978, -2702470331221204145928268130001], [-96380453074820572704882764643163168, 10270256795091714289539429392778], [3628661787102929463754956164609142, -21495081117267502994474049432240], [124493246413738292915218400546514054, 8823333283928927885979572373909], [278742338585538963600600833376846318, 3882089736880857784723150527444], [24062705799688676430590309864023082, -22231884061886834556329968821348], [25453307500981789652428737631960978, -10568741037630953532487811281836], [-40042318489093350840350038122095586, -25951008447511435470936669188112], [-219638473272242293911983399659609482, -1756635073106009625287807120037], [293536841918504142160041901289119350, -588833383965919953914568123288], [171445514800666469391910168567694012, 4576818627592256766862379007918], [-60347021637078897839630654490626486, -3529272601010727768811470189372], [-197691798115303381363058403563444830, 15655163428111065238662581619648], [62379970316150071858796834286226500, 543670457659278998993352947664], [-632584656086685007041462549061259286, -6314218337032900595525653774992], [-410272284791028003285489331342203040, -35387364435296140977415091729424], [165484382919498115352116434170384658, 38782268750656664759045032834707], [-540043236227220454543272722753547510, 26626065126159532818718875042792], [-419503850708389533403005357660114208, -50515917779132904561243978977802], [-479595007804838603939431468757208506, -1681646782679013780901172008980], [300387072298442448360887268881689422, 43119134956336019422212393148728], [-447706090487712057735694064930184002, 33088399166911379542015703665959], [307918528658417930842415922680407734, -7975431746582200523610616226079], [430864390940527921004287088592635280, -34496643419256441518002560074580], [-147118222015949567576997073084380478, -20228869943787209737236246080316], [-122632055754467532466753917032802326, -64893146301499345400268370357623], [57387562471347771664022855225394162, -97976323063365003735746409832608], [418543213177820877394812107777095194, 85793035904316382683815613576765], [1056029028618511257672708462063933858, -43968294280761175316339388255636], [-1403384639394915651018672920964385618, 34784165821652142175427735257776], [1662926546921755350626538575122255040, -64042230492924103613264577118164], [-574418423822448080782555876552888110, 55489395396222555514221218781960], [-2137397092809188585364611039005012442, -84684333795104228346335534387841], [990583827006476709741815896860184854, -45446907507946153848697882515291], [1151174570586348128997044770579616990, -104279670035236112062996633570272], [1935818862897676091718129880102029678, 113285277738732230068117594710780], [2482439380838193800192712053564051280, 105431794768551082379877131505048], [-2636249519027811516776012402351019086, 41184220285217419539999823121553], [-320898674704309453701617575939630128, -127194258271649265450298090169442], [541269992147041961847527748852487858, 96491992757574777316511730363468], [2518362446200261111968102402965553620, 77812847909348283562188900636972], [-902610740472912324839076888935799748, -34353857616743197015953776099514], [-1528637403975658340456910042465691278, 89771366232698585096172729330252], [178025964194240434056762593914153858, -87369990313785140533515028602633], [1786185693415160822020573849511131914, -181040394527370506809120342378167], [-1154079252477433347602337574070706310, 315689882373571058363844957244212], [3940418794491565844973113144185975338, -44803646552141931315026147726988], [307084815531293588672853915339532860, -252064749581604955937064635326476], [4429207830402732180759108421534976532, -32224245710477405125495028557050], [3789899317643785210016138721872395338, 28870637962429905575972131191591], [-3390494677720547107366574322100369288, -72610829496414266142874466194902], [693566856459478175810026044347628838, 338524744636367167781651335072947], [-2000468979371842053890739739157742010, -335059307861244795805063671303984], [-1228301705300290310292762558121699842, -133941016088170525128048781707432], [-1352874009709460311687056307476379080, 457359010935629897524389264181512], [-2808228502645563166644453935324899046, 147167160807005135880015834505449], [5070500395416203371558244392485584832, 339144891301533749320785325300578], [296234760749608919600572471624019060, 393560201509219742094218137617576], [-6700395056834968909949619672130856082, -69735183703376491800979782915069], [-5843003300070661120471665325333780526, -474428063310940186962536019261708], [10483970936009683545686042680512976002, -163855157423865593144440522609440], [5220884996370489936638568732851349834, 51445381304328485352385321877661], [490606425159777542380007590129304690, -281231796761810440878758538775860], [-199856787605565114616169356216482822, -131655770255417926699215763744176], [3610881268460711432064719003687681220, 45477040163954071033750473802836], [-6971291612454515304652750502594775058, 378234446296925736429856179145992], [3899622277786972946023115955906493774, 61675681016413514159272762785117], [-6225377602487402178816318134671156446, -447403858307999098907288664618216], [-14882184297041584948897656731591544266, 304544216815798008219222620337696], [8238445801606814157696243205114344838, -247913807404807438815133074375657], [14082370735611643615883507128962946014, 201130623144007835491649775725793], [-5552808054662970423001445135232191890, -810206096581810376666235450404928], [-3740868821125800882264909462907166582, -500722153231665063401949490909776], [-11977412817436729368408971860516302186, -100710635122276463526650322023412], [14596745181945027140115473130307740740, 381243631280361079773077826881436], [-1353251805271304337559965201464914170, 1102397957903662955322370171407936], [-8319989796579265367843624263786689558, 1610891170409142206432067446866512], [6734528866406559464326860627062387458, 1385871123361190817666787139798559], [8852922374376171322473184834656431298, -1025374626736510867626657096509832], [-7520797533556540990627265605713847738, -1541580809384026563752870194441104], [4673091382779388909496333477382771814, -1720959963838825433467703373823347], [7386002845030852605339844575464309038, 1354789265075861190924407887594620], [29072015943818715085920284607922903040, -813094943733346075553140316969040], [-21470939829365836147432674388072421426, -929872513778684896067646089951568], [-21545853996134014816481647330413617402, -217852268493269527848939057338997], [3619553605561512019866003586272518214, 1912451124700933252156903959737433], [-2755613872230267666932918589241385050, 2589223207466726694654357185810136], [-15100958059873979307202347526082412718, 1498307677618860171229717949951772], [6883111405283834268080835909863915832, 2575752885071087581085555977431750], [-871809610152553181712297960377791962, -972741391759866167103764520885609], [4809969931681982621043677314993060772, -1813498511234165045670581520734898], [40786248024357437502539679888126096114, 1444895009391117737383018572913353], [6434875950575742148497133490435511662, -1416395608780000530678153336950688], [-48427915065891016105908298841104695626, 997380766781214436650175418638377], [-3870499339959677107071486882243824988, 4152219211692850143218183427871890], [-6759390140802110430783198770187120842, -1848977214824550534522672538717596], [47284414755065778035759351082703021674, -81923758842619600375835717447148], [-38285150398040336771351427481022130880, 1294602111422532133364536373589660], [-39861635562552529955575798042236384630, -2995083627654621376223737618023036], [-66495575791306395283121765395532999178, -2240569221162075519836185031764392], [25405462251187249962085552398529847814, -512760054624890620758801809393907], [24625071635912963542311643848602181198, -1946870462471010740544278932421508], [33494852980781192616460978492978693752, 1642119703526567546680865845686354], [48264191219225511542363354293543899898, 3339063908183783608356150966549168], [-74586554305764300250299818955389596890, -1823817479684187582061696021505976], [-28415411238048354704064942737403070348, -481575710945270674380336576020190], [1822022187567495479026325679751602498, 1637474193065779031056838102975520], [105279751056938947384780853039873232780, -1266912703101606363803927648349396], [-87659995878894276770961735394719417866, 3472184760238933485794167361546781], [-116529742825074724742085325270716377402, 1327836924347342418459455925721536], [2363950567516409746867881303736696074, -2313762910912664944063170323196168], [67795969986443610854817284925723706760, -3719322536323313409002882445716676], [25283014116199468409513853104931714738, -11105390836825239854971203383886885], [-28557933794317225521556787693808127768, 6021917340300527672962218653057970], [3160780019763814100829696085767137254, 5404090816636945959883719259010484], [46306582113101857331290309443961324134, -2347755883733043870995438079698799], [125186776558826077255924001877698049590, -4517792807162271321731792941320552], [22839456877120861542760495046228008920, 3862328638470326098444048976566344], [9539358009057039536116167589837836418, 5249280217542594640415449202219832], [16692313343705986802410664682905967198, 11594681536965600357451103640094827], [135229139999551998446744257461107061630, -2423643435404026177640727521490480], [137346795629515715060012291948057500482, 9167266582262812263527813760641136], [110305886842288497704805915807596948458, 2057000003525179134273185216691327], [96388614220040583876642689839662232794, 9803928909081188637672211284486165], [42423188669709352911486079334393608010, 8463434680190186326220078372287320], [125403738200650310827049008409537811300, 12124741915314863431744883818272660], [154740980423433692666948169109760130612, 10252652518466878985687774510504082], [38008201401984846441992992681119625678, 10596985446211722871055410083162984], [-14487621050175007825220200536082917030, -21822621935172131524913186700974940], [-235184414321283449114795519949002760688, -947953456337135659781260978458462], [-140477995818824189054917060224635001866, -278717322127390123271644747277424], [214234907695518864587061737329294715382, 11860155330273433193638154480650224], [331180305409332082087230351511472012638, 2244638838131863455525414837340707], [137807149361034117520449514796102585238, -5880378364249776958476439249791240], [21865187424993026953100050688751151802, 6749983742141863918976985822725028], [-176551433633418447894881835370270314220, 15669282558709855765495270753477524], [25677106058414409024863567595371321938, -12593433618617105637520905593143305], [-146358866140375888090295132021951906406, -4941462732876391594220641521761175], [88336340059016051269149812921481537018, -5388487171755410462266200457154700], [-78019322433879077375660798504433140938, -22565582368649810862071147961546600], [201908965658567399914895542932764264874, 4645011782674472093424999555025392], [74165737858777318049340980983372033160, -22309634759850459462281094868200300], [-334004382569829718352314742402647402182, 8522000677035360959388334298944119], [-297113275447345072498488518360187095128, -7383166067080951757182387458777942], [-140424987958610446585203211899992691186, -35940125260290079264761838312825347], [-203000721963739476620630443417010884090, 30846484078256672752229094229085592], [-247718600969066091056205045350004007842, -10947003577727309251483258435936896], [333016157970080959549117808871689058962, 261119769545933355297708730275948], [-369637902248683072895891232552114717566, -2172499004773188829360244092581819], [14332241009958954708901394284371400258, -20199725731487704927778146250231040], [427567067072552242883383792103571096054, 20923446002404987810390130039922624], [188010510064138508989233638201246356830, -4762164716212623809209017539974344], [1383843423291914893496969915243702972, 28200608765178295392453474029742426], [286732271479320889747342413420365871738, -12117359109989509458523622881524216], [-333186318614189411754029072711762735100, -14967786161055191480881727193475524], [-229678789585072342880119214228520843538, 7737927483625551355692449499088176], [-60713623125902035893321721844054504546, -61565888488724751110585757802365411], [-582159794257500002338797971016294603948, 7727054738314513738000791423552570], [913757025626667019950415486505624221434, -20580226491469504853711805605803764], [-251339119366560420075889373838925598248, -14508088321491202393824294630818034], [-77226686293060070802022909672216400426, 50966363715431927526602723488428072], [-938307724694652802308093860549262168858, 8186701559592287339490617078073120], [-244609786250320123702962732220523725802, 52798628006396691078344384399383863], [890349529189595759887009195834539598430, -8715588071032418492180490070411872], [432745823304965264244407222562287594238, 12919635876319791676864432228367172], [355964265532271370331384406845176236280, 9689797787693569017806002185250812], [178080358543807252040374943823045088032, -22693770978191845019136189740760570], [225791486128559281234762166817670571094, 34338869915419597318716685109572260], [9800940260287901992854325788166565958, 1321372217029436597383982389430379], [334705014970172880031649207681549391034, -69953847321017999197884524993262684], [175537132405818635911937243124409558842, 68260476240375593875238031855843168], [-50172456421978989508802285837585301726, -12905690817882260186645591623333563], [163368376455153439850086903830156964740, -96435390560907512872602080292026520], [320727386625419609573518378665958552534, 41791465483362235278369037236389661], [-216936215993645223587750991685496757362, 48967067798598834445824036363228516], [114884088337110179823640922069892883794, -34075718564098976270214051370662180], [911819318662972778731505175127275976078, 25766626916526480452605368075382071], [461741143164062785256323858467157118642, -61497709730976645818388865823771628], [-301542802267146221364403618682715698568, 100501998880767107671812403763613486], [-2176456252892957279644998695952686435860, -43161286130172253181028642633040428], [-40078845464614405520461985130712662402, -46822685733911273605419634778270709], [1127251733664247516142584788942637701870, 55928793180423021135499294648113528], [434336612778765368125502123376587474492, 158165003657937823357295680616117106], [1082850786216865676410421644000165115794, -8670783120158725002721539130207500], [-2181030960619222311799685741166816672300, 56518965729987955666672085594468892], [1166955260088379583098180278218277203172, -158210021340389393612067464697923910], [-812128061754251282806048073328201263522, -85485930408907861306395937965252192], [772403773357925821937311800483376286490, -166580689690112016333473633937357900], [-721453012478805687972138892630814499386, 51927612363750326140843302508274088], [567365129176509098847175396656422276022, 51222656577075163282432082985043104], [-179111666490683470198387655808044512362, -155594373770988427273891701204175416], [-283703540459523048076311025484062613246, -133578199410916868487522537614032671], [-87575279979694909263036383544263212386, 82825662814178381801566369049900448], [-3032887490648754598938904725633620884060, 31448087479276282787551157457781740], [-2445257976121773499196970199430484596562, -43759195096700842355376419867618697], [341366859986051573437077962149929794492, -77331966594820532476579161307220418], [-1675938290922116522419781241203648339246, 202844840165778552320452179818226024], [2871724687964870771809172411132557489138, 80474972443535605617995786691174999], [-707649288223755330746602715477294782326, 116810332370825287763403191235350097], [2023052547931596456801859728357449159210, -171829001597157185534578687673249820], [438453009973003584488446453136642574978, 220595561009087177755729298390474808], [1905951191998321246373112951619765242660, 245896177348430554256429226938853264], [1479526253061396606989266812268963594054, 180859745121823648412760444169048029], [858115339649938550343918461573780537772, 113346952485566395513583455561898586], [-507287307390966865065038938053700127402, -138139504491079031117265635037356448], [-324320177907128692733836191664837334920, -313085499352717885855961396053693860], [2291561843706060739816688546807190075930, -195199851866639285834121543565921056], [2813238387418572623332053173813991762392, 56690076406504131545033177946634770], [-1266582819743250910633618775706650527938, 291832075412594334629486141896611936], [6062312310045572204321870688512746290470, -232034289065687571143294259851112], [854814553506447535761124650340888895958, -159507908105823222518141011676716452], [-1212770797736785014284513420751074291246, 231560967163139622245220174520149789], [3625242807356599292839305559333173468054, 217397744133984138617012529259984224], [1681051160422614391558258700082740931630, -248000378797544223128012286518916432], [-1266092582148702531570222576892473377668, 296651741774351342085108457028893674], [3558048280760093753499117385022231608594, 160704126830786874379875929592723420], [-5357750589432710903147711501046121588878, -220551216430112648135774561191134672], [954581445829693274923126951615622996938, 209786256277351309089450206674161255], [-232519894268148614613043454541377863860, 391259302804983030491081679842035584], [1027142285784761443624031533865347497118, -15327395493662425218816774882495384], [1048424497902873203878665072970455676434, 9253095758593258973813417735656056], [-1155808455920211891772695835731606666102, -386883649608458844845854507779508509], [-2940134275515258600856266701817867120088, -202117885446020377325766995817523386], [-2331109475032273303210859403980546666546, 195905123505795901963226506706658564], [-4426716591837881993647241834830390270698, 243766354473947767645173363825786408], [155304128572163848531401225562449145920, -381702399282449449619678258956908480], [5630584817677844241985206087419743389034, 97614921736442938848884798705799021], [2587371812670844058343038472191133624774, 61674315001698983678140046595783372], [-1354195480431190804413322397251301618922, 13515591940520867402220236623590531], [1194898305402713478538955138160906870, 7115081938413556364591901792394032], [-2501293131211816781625221763812344670726, -200105173968768031210794951791595948], [-4471707376137807836741416835206997968806, -438415230619887288439343189917980735], [3868279401267310513602765494048405892660, -241268545311890571658702767615283440], [-1753551269367024315014761076031078662042, 354240894079147766313974390025239088], [-4783725936272151429025169014247411397846, -291986472639978128318879092190080536], [-1672920642368364055472568218707829595342, 355354780451545606523679903807893691], [1318756147067593810083157422163357852290, 296557735276020297299366118202163964], [-178712210090010638523104338829253227728, -50214643612824377074108323568035546], [-123124168378876781424629208200219279640, -308983277205618439020176876977704816]]
